#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-form
version:              1.6.7
visibility:           public
id:                   yesod-form-1.6.7-8hjiXpZ4BNG5gsaLuvdJPL
key:                  yesod-form-1.6.7-8hjiXpZ4BNG5gsaLuvdJPL
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).

category:             Web, Yesod
abi:                  3a4ffe946420a5cde4a0a257776506bd
exposed:              True
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Spanish
    Yesod.Form.I18n.Swedish Yesod.Form.Input Yesod.Form.Jquery
    Yesod.Form.MassInput Yesod.Form.Nic Yesod.Form.Types

import-dirs:          /usr/lib/ghc-8.10.2/site-local/yesod-form-1.6.7
library-dirs:         /usr/lib/ghc-8.10.2/site-local/yesod-form-1.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.2/yesod-form-1.6.7
hs-libraries:         HSyesod-form-1.6.7-8hjiXpZ4BNG5gsaLuvdJPL
depends:
    aeson-1.5.5.1-7ZKmq9KLIncxnBfAj9HU2
    attoparsec-0.13.2.4-7uGnKXAWXqp2Qn14d3Hl25 base-4.14.1.0
    blaze-builder-0.4.1.0-G4KXEZbDrFS6c5MmayHGI7
    blaze-html-0.9.1.2-2CxRFZ3pUcb2942dceW5fY
    blaze-markup-0.8.2.7-LxYHHNtMMqd23FQvjJOkWQ
    byteable-0.1.1-FeSdIMqUIcwI3U3IhpOBJ3 bytestring-0.10.10.0
    containers-0.6.2.1 data-default-0.7.1.1-KLr953AsnH0rCiCUM3wfv
    email-validate-2.3.2.13-J4nAdJHjuup7rDwOMd1D1J
    network-uri-2.6.3.0-8tJyeRBDup92wNsuQRxrki
    persistent-2.11.0.2-743j6nHYeNr8Viijc4VTba
    resourcet-1.2.4.2-E1PquPTZKgvLbHxPSs1hvZ
    shakespeare-2.0.25-InP8iySwSEBKoeCQgQIPBs text-1.2.3.2 time-1.9.3
    transformers-0.5.6.2 wai-3.2.2.1-BYB2v4x1FyK8eqy5kz3dj4
    xss-sanitize-0.3.6-EddSxDFYqJ05rnjFwe5UI3
    yesod-core-1.6.18.8-CurW9QTzY3EBjvO5ntfMC0
    yesod-persistent-1.6.0.5-7cO4Eb9G6m7CF6HLrs9PTu

haddock-interfaces:   /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html:         /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

